﻿"""_1261.py

ElectricMachineSetup
"""
from __future__ import annotations

from typing import TYPE_CHECKING, List

from mastapy._internal import constructor, conversion
from mastapy import _0
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_ELECTRIC_MACHINE_SETUP = python_net_import('SMT.MastaAPI.ElectricMachines', 'ElectricMachineSetup')

if TYPE_CHECKING:
    from mastapy.electric_machines import _1300, _1259, _1255


__docformat__ = 'restructuredtext en'
__all__ = ('ElectricMachineSetup',)


class ElectricMachineSetup(_0.APIBase):
    """ElectricMachineSetup

    This is a mastapy class.
    """

    TYPE = _ELECTRIC_MACHINE_SETUP

    class _Cast_ElectricMachineSetup:
        """Special nested class for casting ElectricMachineSetup to subclasses."""

        def __init__(self, parent: 'ElectricMachineSetup'):
            self._parent = parent

        @property
        def electric_machine_setup(self) -> 'ElectricMachineSetup':
            return self._parent

        def __getattr__(self, name: str):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = ''.join(n.capitalize() for n in name.split('_'))
                raise CastException(f'Detected an invalid cast. Cannot cast to type "{class_name}"') from None

    def __init__(self, instance_to_wrap: 'ElectricMachineSetup.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def estimated_material_cost(self) -> 'float':
        """float: 'EstimatedMaterialCost' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.EstimatedMaterialCost

        if temp is None:
            return 0.0

        return temp

    @property
    def mass(self) -> 'float':
        """float: 'Mass' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.Mass

        if temp is None:
            return 0.0

        return temp

    @property
    def name(self) -> 'str':
        """str: 'Name' is the original name of this property."""

        temp = self.wrapped.Name

        if temp is None:
            return ''

        return temp

    @name.setter
    def name(self, value: 'str'):
        self.wrapped.Name = str(value) if value is not None else ''

    @property
    def number_of_air_gap_elements(self) -> 'int':
        """int: 'NumberOfAirGapElements' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.NumberOfAirGapElements

        if temp is None:
            return 0

        return temp

    @property
    def two_d_fe_model_for_electro_magnetic_analysis(self) -> '_1300.TwoDimensionalFEModelForAnalysis[_1259.ElectricMachineMeshingOptions]':
        """TwoDimensionalFEModelForAnalysis[ElectricMachineMeshingOptions]: 'TwoDFEModelForElectroMagneticAnalysis' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.TwoDFEModelForElectroMagneticAnalysis

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)[_1259.ElectricMachineMeshingOptions](temp) if temp is not None else None

    @property
    def eccentricity(self) -> '_1255.Eccentricity':
        """Eccentricity: 'Eccentricity' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.Eccentricity

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def report_names(self) -> 'List[str]':
        """List[str]: 'ReportNames' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ReportNames

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp, str)
        return value

    def generate_electro_magnetic_mesh(self):
        """ 'GenerateElectroMagneticMesh' is the original name of this method."""

        self.wrapped.GenerateElectroMagneticMesh()

    def output_default_report_to(self, file_path: 'str'):
        """ 'OutputDefaultReportTo' is the original name of this method.

        Args:
            file_path (str)
        """

        file_path = str(file_path)
        self.wrapped.OutputDefaultReportTo(file_path if file_path else '')

    def get_default_report_with_encoded_images(self) -> 'str':
        """ 'GetDefaultReportWithEncodedImages' is the original name of this method.

        Returns:
            str
        """

        method_result = self.wrapped.GetDefaultReportWithEncodedImages()
        return method_result

    def output_active_report_to(self, file_path: 'str'):
        """ 'OutputActiveReportTo' is the original name of this method.

        Args:
            file_path (str)
        """

        file_path = str(file_path)
        self.wrapped.OutputActiveReportTo(file_path if file_path else '')

    def output_active_report_as_text_to(self, file_path: 'str'):
        """ 'OutputActiveReportAsTextTo' is the original name of this method.

        Args:
            file_path (str)
        """

        file_path = str(file_path)
        self.wrapped.OutputActiveReportAsTextTo(file_path if file_path else '')

    def get_active_report_with_encoded_images(self) -> 'str':
        """ 'GetActiveReportWithEncodedImages' is the original name of this method.

        Returns:
            str
        """

        method_result = self.wrapped.GetActiveReportWithEncodedImages()
        return method_result

    def output_named_report_to(self, report_name: 'str', file_path: 'str'):
        """ 'OutputNamedReportTo' is the original name of this method.

        Args:
            report_name (str)
            file_path (str)
        """

        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportTo(report_name if report_name else '', file_path if file_path else '')

    def output_named_report_as_masta_report(self, report_name: 'str', file_path: 'str'):
        """ 'OutputNamedReportAsMastaReport' is the original name of this method.

        Args:
            report_name (str)
            file_path (str)
        """

        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportAsMastaReport(report_name if report_name else '', file_path if file_path else '')

    def output_named_report_as_text_to(self, report_name: 'str', file_path: 'str'):
        """ 'OutputNamedReportAsTextTo' is the original name of this method.

        Args:
            report_name (str)
            file_path (str)
        """

        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportAsTextTo(report_name if report_name else '', file_path if file_path else '')

    def get_named_report_with_encoded_images(self, report_name: 'str') -> 'str':
        """ 'GetNamedReportWithEncodedImages' is the original name of this method.

        Args:
            report_name (str)

        Returns:
            str
        """

        report_name = str(report_name)
        method_result = self.wrapped.GetNamedReportWithEncodedImages(report_name if report_name else '')
        return method_result

    @property
    def cast_to(self) -> 'ElectricMachineSetup._Cast_ElectricMachineSetup':
        return self._Cast_ElectricMachineSetup(self)
